@@ -1,3 +1,3 @@
-from .stat_names import *
 from .seasons import seasons
 from .operators import operator_dict
+from .weapons import WEAPONS_DICT
